@@ -1,8 +1,16 @@
+"""
+Base file that contains the core classes that are used in dyc.
+"""
 import fileinput
-from utils import all_files_generator, get_file_lines
+from .utils import all_files_generator, get_file_lines, is_one_line_method
 
 
 class Builder(object):
+    def __init__(self, filename, config, placeholders=False):
+        self.filename = filename
+        self.config = config
+        self.placeholders = placeholders
+
     details = dict()
 
     def initialize(self, change=None):
@@ -14,13 +22,34 @@ class Builder(object):
 
         patches = []
         if change:
-            patches = change.get('additions')
+            patches = change.get("additions")
+
+        fileLines = list(fileinput.input(self.filename))
+        i = 0
 
         for line in fileinput.input(self.filename):
             filename = fileinput.filename()
             lineno = fileinput.lineno()
-            keywords = self.config.get('keywords')
-            found = len(filter(lambda word: word.lstrip() in keywords, line.split(' '))) > 0
+            keywords = self.config.get("keywords")
+            foundList = [
+                word.lstrip() for word in line.split(" ") if word.lstrip() in keywords
+            ]
+            found = len(foundList) > 0
+            # Checking an unusual format in method declaration
+            if foundList:
+                openP = line.count("(")
+                closeP = line.count(")")
+                if openP == closeP:
+                    pass
+                else:
+                    pos = i
+                    while openP != closeP:
+                        pos += 1
+                        line += fileLines[pos]
+                        openP = line.count("(")
+                        closeP = line.count(")")
+                    lineno = pos + 1
+            i = i + 1
 
             if change and found:
                 found = self._is_line_part_of_patches(lineno, line, patches)
@@ -30,7 +59,9 @@ class Builder(object):
 
             if found:
                 length = get_file_lines(filename)
-                result = self.extract_and_set_information(filename, lineno, line, length)
+                result = self.extract_and_set_information(
+                    filename, lineno, line, length
+                )
                 if self.validate(result):
                     self.details[filename][result.name] = result
 
@@ -45,13 +76,21 @@ class Builder(object):
         """
         result = False
         for change in patches:
-            start, end = change.get('hunk')
+            start, end = change.get("hunk")
             if start <= lineno <= end:
-                patch = change.get('patch')
-                found = filter(lambda l: line.replace('\n', '') == l, patch.split('\n'))
+                patch = change.get("patch")
+                found = filter(lambda l: line.replace("\n", "") == l, patch.split("\n"))
                 if found:
                     result = True
                     break
+
+                # Try to catch unusual declared methods
+                broken_lines = line.split("\n")
+                if len(broken_lines) and not is_one_line_method(
+                    broken_lines[0], self.config.get("keywords")
+                ):
+                    result = True
+                    break
         return result
 
     def clear(self, filename):
@@ -77,9 +116,9 @@ class Builder(object):
         pass
 
 
-class FilesDirector():
+class FilesDirector:
 
-    WILD_CARD = ['.', '*']
+    WILD_CARD = [".", "*"]
 
     def prepare_files(self, files=[]):
         """
@@ -112,9 +151,9 @@ class FilesDirector():
         ----------
         list files: Pre-given files list
         """
-        if self.config.get('file_list'):
+        if self.config.get("file_list"):
             # File list has already been passed
-            self.file_list = self.config.get('file_list')
+            self.file_list = self.config.get("file_list")
             return
 
         if len(files):
@@ -128,7 +167,7 @@ class FilesDirector():
         self.file_list = result
 
 
-class FormatsDirector():
+class FormatsDirector:
 
     formats = dict()
 
@@ -136,11 +175,12 @@ class FormatsDirector():
         """
         Function that prepares allowed formats
         """
-        self.formats = {ext.get('extension'): ext for ext in self.config.get('formats')}
+        self.formats = {ext.get("extension"): ext for ext in self.config.get("formats")}
 
 
 class Processor(FilesDirector, FormatsDirector):
     """Subclass process that runs complete lifecycle for DYC"""
+
     def start(self):
         """
         TODO Method wrapper for starting the process
@@ -165,4 +205,8 @@ class Processor(FilesDirector, FormatsDirector):
         """
         Property that returns all the allowed extensions
         """
-        return filter(None, map(lambda fmt: fmt.get('extension'), self.config.get('formats')))
+        return list(
+            filter(
+                None, map(lambda fmt: fmt.get("extension"), self.config.get("formats"))
+            )
+        )
\ No newline at end of file
